@@ -185,6 +185,42 @@ func TestWithDefaults(t *testing.T) {
 			},
 			goBinary: "go",
 		},
+		"go first class targets": {
+			build: config.Build{
+				ID:      "foo3",
+				Binary:  "foo",
+				Targets: []string{goStableFirstClassTargetsName},
+			},
+			targets:  go118FirstClassTargets,
+			goBinary: "go",
+		},
+		"go 1.18 first class targets": {
+			build: config.Build{
+				ID:      "foo3",
+				Binary:  "foo",
+				Targets: []string{go118FirstClassTargetsName},
+			},
+			targets:  go118FirstClassTargets,
+			goBinary: "go",
+		},
+		"go 1.18 first class targets plus custom": {
+			build: config.Build{
+				ID:      "foo3",
+				Binary:  "foo",
+				Targets: []string{"linux_amd64_v1", go118FirstClassTargetsName, "darwin_amd64_v2"},
+			},
+			targets:  append(go118FirstClassTargets, "darwin_amd64_v2"),
+			goBinary: "go",
+		},
+		"repeatin targets": {
+			build: config.Build{
+				ID:      "foo3",
+				Binary:  "foo",
+				Targets: []string{go118FirstClassTargetsName, go118FirstClassTargetsName, goStableFirstClassTargetsName},
+			},
+			targets:  go118FirstClassTargets,
+			goBinary: "go",
+		},
 	} {
 		t.Run(name, func(t *testing.T) {
 			if testcase.build.GoBinary != "" && testcase.build.GoBinary != "go" {
@@ -205,6 +241,21 @@ func TestWithDefaults(t *testing.T) {
 	}
 }
 
+func TestDefaults(t *testing.T) {
+	t.Run("command not set", func(t *testing.T) {
+		build, err := Default.WithDefaults(config.Build{})
+		require.NoError(t, err)
+		require.Equal(t, "build", build.Command)
+	})
+	t.Run("command set", func(t *testing.T) {
+		build, err := Default.WithDefaults(config.Build{
+			Command: "test",
+		})
+		require.NoError(t, err)
+		require.Equal(t, "test", build.Command)
+	})
+}
+
 // createFakeGoBinaryWithVersion creates a temporary executable with the
 // given name, which will output a go version string with the given version.
 //  The temporary directory created by this function will be placed in the PATH
@@ -301,6 +352,7 @@ func TestBuild(t *testing.T) {
 					"linux_mips64le_softfloat",
 				},
 				GoBinary: "go",
+				Command:  "build",
 				BuildDetails: config.BuildDetails{
 					Asmflags: []string{".=", "all="},
 					Gcflags:  []string{"all="},
@@ -479,6 +531,7 @@ func TestBuildCodeInSubdir(t *testing.T) {
 					runtimeTarget,
 				},
 				GoBinary: "go",
+				Command:  "build",
 			},
 		},
 	}
@@ -506,6 +559,7 @@ func TestBuildWithDotGoDir(t *testing.T) {
 				Binary:   "foo",
 				Targets:  []string{runtimeTarget},
 				GoBinary: "go",
+				Command:  "build",
 			},
 		},
 	}
@@ -534,6 +588,7 @@ func TestBuildFailed(t *testing.T) {
 					runtimeTarget,
 				},
 				GoBinary: "go",
+				Command:  "build",
 			},
 		},
 	}
@@ -648,15 +703,7 @@ func TestRunPipeWithoutMainFunc(t *testing.T) {
 		folder := testlib.Mktmp(t)
 		writeMainWithoutMainFunc(t, folder)
 		config := config.Project{
-			Builds: []config.Build{
-				{
-					Binary: "no-main",
-					Hooks:  config.BuildHookConfig{},
-					Targets: []string{
-						runtimeTarget,
-					},
-				},
-			},
+			Builds: []config.Build{{Binary: "no-main"}},
 		}
 		ctx := context.New(config)
 		ctx.Git.CurrentTag = "5.6.7"
@@ -703,6 +750,28 @@ func TestRunPipeWithoutMainFunc(t *testing.T) {
 	})
 }
 
+func TestBuildTests(t *testing.T) {
+	folder := testlib.Mktmp(t)
+	writeTest(t, folder)
+	config := config.Project{
+		Builds: []config.Build{{
+			Binary:  "foo.test",
+			Command: "test",
+			BuildDetails: config.BuildDetails{
+				Flags: []string{"-c"},
+			},
+		}},
+	}
+	ctx := context.New(config)
+	ctx.Git.CurrentTag = "5.6.7"
+	ctx.Config.Builds[0].NoMainCheck = true
+	build, err := Default.WithDefaults(config.Builds[0])
+	require.NoError(t, err)
+	require.NoError(t, Default.Build(ctx, build, api.Options{
+		Target: runtimeTarget,
+	}))
+}
+
 func TestRunPipeWithProxiedRepo(t *testing.T) {
 	folder := testlib.Mktmp(t)
 	out, err := exec.Command("git", "clone", "https://github.com/goreleaser/goreleaser", "-b", "v0.161.1", "--depth=1", ".").CombinedOutput()
@@ -744,6 +813,7 @@ import _ "github.com/goreleaser/goreleaser"
 					runtimeTarget,
 				},
 				GoBinary: "go",
+				Command:  "build",
 			},
 		},
 	}
@@ -771,6 +841,7 @@ func TestRunPipeWithMainFuncNotInMainGoFile(t *testing.T) {
 					runtimeTarget,
 				},
 				GoBinary: "go",
+				Command:  "build",
 			},
 		},
 	}
@@ -925,6 +996,7 @@ func TestBuildModTimestamp(t *testing.T) {
 				},
 				ModTimestamp: fmt.Sprintf("%d", modTime.Unix()),
 				GoBinary:     "go",
+				Command:      "build",
 			},
 		},
 	}
@@ -977,7 +1049,7 @@ func TestBuildGoBuildLine(t *testing.T) {
 		ctx.Git.Commit = "aaa"
 
 		line, err := buildGoBuildLine(ctx, config.Builds[0], api.Options{
-			Path:   "foo",
+			Path:   config.Builds[0].Binary,
 			Goos:   "linux",
 			Goarch: "amd64",
 		}, &artifact.Artifact{}, []string{})
@@ -995,7 +1067,9 @@ func TestBuildGoBuildLine(t *testing.T) {
 				Tags:     []string{"tag1", "tag2"},
 				Ldflags:  []string{"ldflag1", "ldflag2"},
 			},
+			Binary:   "foo",
 			GoBinary: "go",
+			Command:  "build",
 		}, []string{
 			"go", "build",
 			"-flag1", "-flag2",
@@ -1031,6 +1105,8 @@ func TestBuildGoBuildLine(t *testing.T) {
 				},
 			},
 			GoBinary: "go",
+			Binary:   "foo",
+			Command:  "build",
 		}, []string{
 			"go", "build",
 			"-flag3",
@@ -1046,9 +1122,23 @@ func TestBuildGoBuildLine(t *testing.T) {
 		requireEqualCmd(t, config.Build{
 			Main:     ".",
 			GoBinary: "go",
+			Command:  "build",
+			Binary:   "foo",
 		}, strings.Fields("go build -o foo ."))
 	})
 
+	t.Run("test", func(t *testing.T) {
+		requireEqualCmd(t, config.Build{
+			Main:     ".",
+			GoBinary: "go",
+			Command:  "test",
+			Binary:   "foo.test",
+			BuildDetails: config.BuildDetails{
+				Flags: []string{"-c"},
+			},
+		}, strings.Fields("go test -c -o foo.test ."))
+	})
+
 	t.Run("ldflags1", func(t *testing.T) {
 		requireEqualCmd(t, config.Build{
 			Main: ".",
@@ -1056,6 +1146,8 @@ func TestBuildGoBuildLine(t *testing.T) {
 				Ldflags: []string{"-s -w -X main.version={{.Version}} -X main.commit={{.Commit}} -X main.builtBy=goreleaser"},
 			},
 			GoBinary: "go",
+			Command:  "build",
+			Binary:   "foo",
 		}, []string{
 			"go", "build",
 			"-ldflags=-s -w -X main.version=1.2.3 -X main.commit=aaa -X main.builtBy=goreleaser",
@@ -1070,6 +1162,8 @@ func TestBuildGoBuildLine(t *testing.T) {
 				Ldflags: []string{"-s -w", "-X main.version={{.Version}}"},
 			},
 			GoBinary: "go",
+			Binary:   "foo",
+			Command:  "build",
 		}, []string{"go", "build", "-ldflags=-s -w -X main.version=1.2.3", "-o", "foo", "."})
 	})
 }
@@ -1260,6 +1354,20 @@ func writeGoodMain(t *testing.T, folder string) {
 	))
 }
 
+func writeTest(t *testing.T, folder string) {
+	t.Helper()
+	require.NoError(t, os.WriteFile(
+		filepath.Join(folder, "main_test.go"),
+		[]byte("package main\nimport\"testing\"\nfunc TestFoo(t *testing.T) {t.Log(\"OK\")}"),
+		0o644,
+	))
+	require.NoError(t, os.WriteFile(
+		filepath.Join(folder, "go.mod"),
+		[]byte("module foo\n"),
+		0o666,
+	))
+}
+
 func assertContainsError(t *testing.T, err error, s string) {
 	t.Helper()
 	require.Error(t, err)
