@@ -4,9 +4,7 @@ package deprecate
 
 import (
 	"bytes"
-	"io"
 	"strings"
-	"sync"
 	"text/template"
 
 	"github.com/apex/log"
@@ -17,24 +15,6 @@ import (
 
 const baseURL = "https://goreleaser.com/deprecations#"
 
-// NewWriter return a io.Writer that notices deprecations.
-func NewWriter(ctx *context.Context) io.Writer {
-	return &writer{ctx: ctx}
-}
-
-type writer struct {
-	ctx  *context.Context
-	once sync.Once
-}
-
-func (w *writer) Write(p []byte) (n int, err error) {
-	w.once.Do(func() {
-		w.ctx.Deprecated = true
-	})
-	log.Warn(color.New(color.Bold, color.FgHiYellow).Sprintf("DEPRECATED: " + strings.TrimSuffix(string(p), "\n")))
-	return len(p), nil
-}
-
 // Notice warns the user about the deprecation of the given property.
 func Notice(ctx *context.Context, property string) {
 	NoticeCustom(ctx, property, "`{{ .Property }}` should not be used anymore, check {{ .URL }} for more info")
