@@ -8,12 +8,11 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
-	"sort"
 	"strings"
 	"sync"
 
 	"github.com/apex/log"
-	"github.com/goreleaser/fileglob"
+	"github.com/goreleaser/goreleaser/internal/archivefiles"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/ids"
 	"github.com/goreleaser/goreleaser/internal/semerrgroup"
@@ -84,6 +83,10 @@ func (Pipe) Run(ctx *context.Context) error {
 	g := semerrgroup.New(ctx.Parallelism)
 	for i, archive := range ctx.Config.Archives {
 		archive := archive
+		if archive.Meta {
+			return createMeta(ctx, archive)
+		}
+
 		filter := []artifact.Filter{artifact.Or(
 			artifact.ByType(artifact.Binary),
 			artifact.ByType(artifact.UniversalBinary),
@@ -120,11 +123,18 @@ func checkArtifacts(artifacts map[string][]*artifact.Artifact) error {
 	return ErrArchiveDifferentBinaryCount
 }
 
+func createMeta(ctx *context.Context, arch config.Archive) error {
+	return doCreate(ctx, arch, nil, arch.Format, tmpl.New(ctx))
+}
+
 func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Artifact) error {
+	template := tmpl.New(ctx).WithArtifact(binaries[0], arch.Replacements)
 	format := packageFormat(arch, binaries[0].Goos)
-	folder, err := tmpl.New(ctx).
-		WithArtifact(binaries[0], arch.Replacements).
-		Apply(arch.NameTemplate)
+	return doCreate(ctx, arch, binaries, format, template)
+}
+
+func doCreate(ctx *context.Context, arch config.Archive, binaries []*artifact.Artifact, format string, template *tmpl.Template) error {
+	folder, err := template.Apply(arch.NameTemplate)
 	if err != nil {
 		return err
 	}
@@ -149,20 +159,24 @@ func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Arti
 	log := log.WithField("archive", archivePath)
 	log.Info("creating")
 
-	template := tmpl.New(ctx).
-		WithArtifact(binaries[0], arch.Replacements)
 	wrap, err := template.Apply(wrapFolder(arch))
 	if err != nil {
 		return err
 	}
-
-	a := NewEnhancedArchive(archive.New(archiveFile), wrap)
+	a, err := archive.New(archiveFile, format)
+	if err != nil {
+		return err
+	}
+	a = NewEnhancedArchive(a, wrap)
 	defer a.Close()
 
-	files, err := findFiles(template, arch.Files)
+	files, err := archivefiles.Eval(template, arch.Files)
 	if err != nil {
 		return fmt.Errorf("failed to find files to archive: %w", err)
 	}
+	if arch.Meta && len(files) == 0 {
+		return fmt.Errorf("no files found")
+	}
 	for _, f := range files {
 		if err = a.Add(f); err != nil {
 			return fmt.Errorf("failed to add: '%s' -> '%s': %w", f.Source, f.Destination, err)
@@ -178,24 +192,28 @@ func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Arti
 		}
 		bins = append(bins, binary.Name)
 	}
-	ctx.Artifacts.Add(&artifact.Artifact{
-		Type:    artifact.UploadableArchive,
-		Name:    folder + "." + format,
-		Path:    archivePath,
-		Goos:    binaries[0].Goos,
-		Goarch:  binaries[0].Goarch,
-		Goarm:   binaries[0].Goarm,
-		Gomips:  binaries[0].Gomips,
-		Goamd64: binaries[0].Goamd64,
+	art := &artifact.Artifact{
+		Type: artifact.UploadableArchive,
+		Name: folder + "." + format,
+		Path: archivePath,
 		Extra: map[string]interface{}{
 			artifact.ExtraBuilds:    binaries,
 			artifact.ExtraID:        arch.ID,
 			artifact.ExtraFormat:    arch.Format,
 			artifact.ExtraWrappedIn: wrap,
 			artifact.ExtraBinaries:  bins,
-			artifact.ExtraReplaces:  binaries[0].Extra[artifact.ExtraReplaces],
 		},
-	})
+	}
+	if len(binaries) > 0 {
+		art.Goos = binaries[0].Goos
+		art.Goarch = binaries[0].Goarch
+		art.Goarm = binaries[0].Goarm
+		art.Gomips = binaries[0].Gomips
+		art.Goamd64 = binaries[0].Goamd64
+		art.Extra[artifact.ExtraReplaces] = binaries[0].Extra[artifact.ExtraReplaces]
+	}
+
+	ctx.Artifacts.Add(art)
 	return nil
 }
 
@@ -243,66 +261,6 @@ func skip(ctx *context.Context, archive config.Archive, binaries []*artifact.Art
 	return nil
 }
 
-func findFiles(template *tmpl.Template, files []config.File) ([]config.File, error) {
-	var result []config.File
-	for _, f := range files {
-		replaced, err := template.Apply(f.Source)
-		if err != nil {
-			return result, fmt.Errorf("failed to apply template %s: %w", f.Source, err)
-		}
-
-		files, err := fileglob.Glob(replaced)
-		if err != nil {
-			return result, fmt.Errorf("globbing failed for pattern %s: %w", f.Source, err)
-		}
-
-		for _, file := range files {
-			result = append(result, config.File{
-				Source:      file,
-				Destination: destinationFor(f, file),
-				Info:        f.Info,
-			})
-		}
-	}
-
-	sort.Slice(result, func(i, j int) bool {
-		return result[i].Destination < result[j].Destination
-	})
-
-	return unique(result), nil
-}
-
-// remove duplicates
-func unique(in []config.File) []config.File {
-	var result []config.File
-	exist := map[string]string{}
-	for _, f := range in {
-		if current := exist[f.Destination]; current != "" {
-			log.Warnf(
-				"file '%s' already exists in archive as '%s' - '%s' will be ignored",
-				f.Destination,
-				current,
-				f.Source,
-			)
-			continue
-		}
-		exist[f.Destination] = f.Source
-		result = append(result, f)
-	}
-
-	return result
-}
-
-func destinationFor(f config.File, path string) string {
-	if f.Destination == "" {
-		return path
-	}
-	if f.StripParent {
-		return filepath.Join(f.Destination, filepath.Base(path))
-	}
-	return filepath.Join(f.Destination, path)
-}
-
 func packageFormat(archive config.Archive, platform string) string {
 	for _, override := range archive.FormatOverrides {
 		if strings.HasPrefix(platform, override.Goos) {
